import {
  select,
  json,
  tsv,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';
import { map } from './map';


const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

const textLabel = g.append('text')
      .attr('class', 'label')
	  .attr("transform", d => `translate(480, -10)`)
      .text('');

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));


//Get geo data from world-atlas
Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {
  
  const countryName = tsvData.reduce((accumulator, d) => {
    accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
  
  // render 
  const render = () => {
  	map(g, {
    	updateTextLabel,
      	setOnClick,
      	countryName,
      	topoJSONdata,
      	pathGenerator,
      	selectedCountry
    });
  };
  
  let selectedCountry = null;
  
  // update text label and re-render
  const updateTextLabel = d => {
    textLabel.text(countryName[d]);
    render();
  };
  
  const setOnClick = d => {
    selectedCountry = d.id;
    updateTextLabel(selectedCountry);
    render();
  	//console.log(d);
  };
  
  
  
  render();
});